@@ -198,6 +198,11 @@ struct ServerSocketConfig {
 
   FizzConfig fizzConfig;
 
+  /**
+   * If supported prefer using IoUring sockets
+   */
+  bool preferIoUring{false};
+
   /**
    * A map containing custom configs.
    */
